@@ -217,7 +217,10 @@ class WPlotManager(Ui_WPlotManager, QWidget):
             self.w_vect_selector.hide()
 
         self.w_axis_manager.set_axis_widgets(
-            self.data, axes_request_list, frozen_type, is_keep_config=is_keep_config
+            self.data,
+            axes_request_list,
+            frozen_type,
+            is_keep_config=is_keep_config,
         )
         self.update_range(
             unit=unit,
